import type { ComputedRef, InjectionKey } from 'vue';
import type { RouteLocationNormalizedLoaded } from 'vuepress/client';
import type { RecoThemeData, RecoThemeNormalPageFrontmatter, SeriesConfigArray, SeriesConfigObject } from '../../types';
export interface NavItem {
    text: string;
    ariaLabel?: string;
}
export interface NavGroup<T> extends NavItem {
    children: T[];
}
export interface NavLink extends NavItem {
    link: string;
    rel?: string;
    target?: string;
}
export interface ResolvedSeriesItem extends Partial<NavLink> {
    text?: string;
    children?: ResolvedSeriesItem[];
    collapsible?: boolean;
}
export type SeriesItemsRef = ComputedRef<ResolvedSeriesItem[]>;
export declare const seriesItemsSymbol: InjectionKey<SeriesItemsRef>;
export declare const useSeriesItems: () => SeriesItemsRef;
export declare const resolveSeriesItems: (frontmatter: RecoThemeNormalPageFrontmatter, themeLocal: RecoThemeData, route: RouteLocationNormalizedLoaded, autoSeries: any) => ResolvedSeriesItem[];
/**
 * Resolve series items if the config is an array
 */
export declare const resolveArraySeriesItems: (seriesPath: string, seriesConfig: SeriesConfigArray) => ResolvedSeriesItem[];
/**
 * Resolve series items if the config is a key -> value (path-prefix -> array) object
 */
export declare const resolveMultiSeriesItems: (seriesConfig: SeriesConfigObject, route: RouteLocationNormalizedLoaded) => ResolvedSeriesItem[];
