import { inject } from 'vue';
import { isPlainObject, isString, resolveLocalePath } from 'vuepress/shared';
import { getNavLink } from './getNavLink.js';
export const seriesItemsSymbol = Symbol('seriesItems');
export const useSeriesItems = () => {
    const seriesItems = inject(seriesItemsSymbol);
    if (!seriesItems) {
        throw new Error('useSeriesItems() is called without provider.');
    }
    return seriesItems;
};
export const resolveSeriesItems = (frontmatter, themeLocal, route, autoSeries) => {
    // get series config from frontmatter > themeConfig
    let seriesConfig = themeLocal.series ?? {};
    seriesConfig = {
        ...autoSeries,
        ...seriesConfig,
    };
    // 解决
    // resolve series items according to the config
    if (frontmatter.home) {
        return [];
    }
    if (isPlainObject(seriesConfig)) {
        return resolveMultiSeriesItems(seriesConfig, route);
    }
    return [];
};
/**
 * Resolve series items if the config is an array
 */
export const resolveArraySeriesItems = (seriesPath, seriesConfig) => {
    const handleChildItem = (item) => {
        let childItem;
        if (isString(item)) {
            const link = item.includes(seriesPath) ? item : `${seriesPath}${item}`;
            childItem = getNavLink(link);
        }
        else {
            childItem = item;
        }
        return childItem;
    };
    return seriesConfig.map((item) => {
        if (isString(item)) {
            const link = item.includes(seriesPath) ? item : `${seriesPath}${item}`;
            return getNavLink(link);
        }
        return {
            ...item,
            // @ts-ignore
            children: item.children.map(subItem => handleChildItem(subItem)),
        };
    });
};
/**
 * Resolve series items if the config is a key -> value (path-prefix -> array) object
 */
export const resolveMultiSeriesItems = (seriesConfig, route) => {
    const seriesPath = resolveLocalePath(seriesConfig, decodeURIComponent(route.path));
    const matchedSeriesConfig = seriesConfig[seriesPath] ?? [];
    return resolveArraySeriesItems(seriesPath, matchedSeriesConfig);
};
